/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.ifeed.el;

import se.vgregion.ifeed.types.IFeed;
import se.vgregion.ifeed.types.Ownership;

import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.model.Role;
import com.liferay.portal.model.User;

public class AccessGuard {

	public static boolean haveRole(User user, String nameOfAccessRole) throws SystemException {
		for (Role role : user.getRoles()) {
			if (nameOfAccessRole.equals(role.getName())) {
				return true;
			}
		}
		return false;
	}

	public static boolean mayEditAllFeeds(User user) throws SystemException {
		return haveRole(user, "iFeed-admin");
	}

	public static boolean mayEditFeed(User user, IFeed feed) {
		try {
			if (user == null) {
				return false;
			}
			if (mayEditAllFeeds(user)) {
				return true;
			}
		} catch (SystemException se) {
			throw new RuntimeException(se);
		}
		if (user.getScreenName().equals(feed.getUserId())) {
			return true;
		}

		for (Ownership ownership : feed.getOwnerships()) {
			if (user.getScreenName().equals(ownership.getUserId())) {
				return true;
			}
		}

		return false;
	}

}
